@@ -14,10 +14,10 @@ $EM_CONF[$_EXTKEY] = array (
   'title' => 'Startsite bp15 + bootstrap 5 + typo3 13',
   'description' => 'bootstrap 5 per bootstrap package 15, finisher per Powemail',
   'category' => 'misc',
-  'version' => '8.2.3',
-  'state' => 'stable',
+  'version' => '8.2.4',
+  'state' => 'dev',
   'uploadfolder' => false,
-  'clearcacheonload' => false,
+  'clearcacheonload' => true,
   'author' => 'Alex Tuveri',
   'author_email' => 'at@specialistaweb.it',
   'author_company' => 'specialistaweb.it',
